@@ -54,6 +54,7 @@ from cloudify_rest_client.deployment_modifications import (
     DeploymentModificationsClient)
 from cloudify_rest_client.inter_deployment_dependencies import (
     InterDeploymentDependencyClient)
+from cloudify_rest_client.labels import DeploymentsLabelsClient
 
 try:
     from requests_kerberos import HTTPKerberosAuth
@@ -279,6 +280,16 @@ class HTTPClient(object):
                 expected_status_code=expected_status_code, stream=stream,
                 verify=self.get_request_verify(), timeout=timeout)
         except requests.exceptions.SSLError as e:
+            # Special handling: SSL Verification Error.
+            # We'd have liked to use `__context__` but this isn't supported in
+            # Py26, so as long as we support Py26, we need to go about this
+            # awkwardly.
+            if len(e.args) > 0 and 'CERTIFICATE_VERIFY_FAILED' in str(
+                    e.args[0]):
+                raise requests.exceptions.SSLError(
+                    'Certificate verification failed; please ensure that the '
+                    'certificate presented by Cloudify Manager is trusted '
+                    '(underlying reason: {0})'.format(e))
             raise requests.exceptions.SSLError(
                 'An SSL-related error has occurred. This can happen if the '
                 'specified REST certificate does not match the certificate on '
@@ -463,3 +474,4 @@ class CloudifyClient(object):
         self.cluster_status = ClusterStatusClient(self._client)
         self.inter_deployment_dependencies = InterDeploymentDependencyClient(
             self._client)
+        self.deployments_labels = DeploymentsLabelsClient(self._client)
